netapp_ontap.models.nas API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nas`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NasSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Nas object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application_components: List[NasApplicationComponents] GET POST PATCH`

    The application_components field of the nas.

  `cifs_access: List[AppCifsAccess] GET POST`

    The list of CIFS access controls. You must provide either 'user_or_group' or 'access' to enable CIFS access.

  `cifs_share_name: str GET POST`

    The name of the CIFS share. Usage: <Share>

  `exclude_aggregates: List[NasExcludeAggregates] GET POST`

    The exclude_aggregates field of the nas.

  `nfs_access: List[AppNfsAccess] GET POST`

    The list of NFS access controls. You must provide either 'host' or 'access' to enable NFS access.

  `protection_type: NasProtectionType GET POST PATCH`

    The protection_type field of the nas.